@@ -8,9 +8,9 @@ of stack usage.
 
 from xdis.opcodes.base import (
     def_op,
+    extended_format_ATTR,
     extended_format_CALL_FUNCTION,
     finalize_opcodes,
-    format_CALL_FUNCTION_pos_name_encoded,
     format_MAKE_FUNCTION_default_argc,
     format_extended_arg,
     init_opdata,
@@ -62,6 +62,8 @@ opcode_arg_fmt = {
 }
 
 opcode_extended_fmt = {
+    "LOAD_ATTR": extended_format_ATTR,
     "CALL_FUNCTION": extended_format_CALL_FUNCTION,
+    "STORE_ATTR": extended_format_ATTR,
 }
 finalize_opcodes(l)
