@@ -19,7 +19,7 @@ CPython 3.9 bytecode opcodes
 This is a like Python 3.9's opcode.py
 """
 
-from xdis.opcodes.base import(
+from xdis.opcodes.base import (
     def_op,
     extended_format_ATTR,
     extended_format_RETURN_VALUE,
@@ -27,8 +27,8 @@ from xdis.opcodes.base import(
     init_opdata,
     jabs_op,
     rm_op,
-    update_pj3
-    )
+    update_pj3,
+)
 
 from xdis.opcodes.opcode_36 import (
     extended_format_CALL_FUNCTION,
@@ -51,19 +51,20 @@ l = locals()
 
 init_opdata(l, opcode_38, version)
 
+# fmt: off
 # These are removed since 3.8...
-rm_op(l, "BEGIN_FINALLY", 53)
-rm_op(l, "WITH_CLEANUP_START", 81)
+rm_op(l, "BEGIN_FINALLY",       53)
+rm_op(l, "WITH_CLEANUP_START",  81)
 rm_op(l, "WITH_CLEANUP_FINISH", 82)
-rm_op(l, "END_FINALLY", 88)
-rm_op(l, "BUILD_LIST_UNPACK", 149)
-rm_op(l, "BUILD_MAP_UNPACK", 150)
+rm_op(l, "END_FINALLY",         88)
+rm_op(l, "BUILD_LIST_UNPACK",  149)
+rm_op(l, "BUILD_MAP_UNPACK",   150)
 rm_op(l, "BUILD_MAP_UNPACK_WITH_CALL", 151)
 rm_op(l, "BUILD_TUPLE_UNPACK", 152)
-rm_op(l, "BUILD_SET_UNPACK", 153)
+rm_op(l, "BUILD_SET_UNPACK",   153)
 rm_op(l, "BUILD_TUPLE_UNPACK_WITH_CALL", 158)
-rm_op(l, "CALL_FINALLY", 162)
-rm_op(l, "POP_FINALLY", 163)
+rm_op(l, "CALL_FINALLY",       162)
+rm_op(l, "POP_FINALLY",        163)
 
 
 # These are new since Python 3.9
@@ -85,9 +86,11 @@ def_op(l, 'DICT_UPDATE',            165,   2, 1)
 
 format_value_flags = opcode_38.format_value_flags
 
+
 def format_extended_is_op(arg):
     return "is" if arg == 0 else "is not"
 
+
 def format_extended_contains_op(arg):
     return "in" if arg == 0 else "not in"
 
@@ -96,23 +99,24 @@ opcode_arg_fmt = {
     "BUILD_MAP_UNPACK_WITH_CALL": format_BUILD_MAP_UNPACK_WITH_CALL,
     "CALL_FUNCTION_EX": format_CALL_FUNCTION_EX,
     "CALL_FUNCTION_KW": format_CALL_FUNCTION_KW,
-    'CONTAINS_OP': format_extended_contains_op,
-    'EXTENDED_ARG': format_extended_arg36,
-    'FORMAT_VALUE': format_value_flags,
-    'IS_OP': format_extended_is_op,
-    'MAKE_FUNCTION': format_MAKE_FUNCTION_flags,
-    "RAISE_VARARGS": format_RAISE_VARARGS
+    "CONTAINS_OP":      format_extended_contains_op,
+    "EXTENDED_ARG":     format_extended_arg36,
+    "FORMAT_VALUE":     format_value_flags,
+    "IS_OP":            format_extended_is_op,
+    "MAKE_FUNCTION":    format_MAKE_FUNCTION_flags,
+    "RAISE_VARARGS":    format_RAISE_VARARGS,
 }
 
 opcode_extended_fmt = {
     "CALL_FUNCTION": extended_format_CALL_FUNCTION,
-    "LOAD_ATTR": extended_format_ATTR,
-    "CALL_METHOD": extended_format_CALL_METHOD,
+    "CALL_METHOD":   extended_format_CALL_METHOD,
+    "LOAD_ATTR":     extended_format_ATTR,
     "MAKE_FUNCTION": extended_format_MAKE_FUNCTION,
     "RAISE_VARARGS": extended_format_RAISE_VARARGS,
-    "RETURN_VALUE": extended_format_RETURN_VALUE,
-    "STORE_ATTR": extended_format_ATTR,
+    "RETURN_VALUE":  extended_format_RETURN_VALUE,
+    "STORE_ATTR":    extended_format_ATTR,
 }
+# fmt: on
 
 update_pj3(globals(), l)
 
